# cppcpyutils

Utilities for image processing pipelines at the Compact Plants Phenomics Center at Washingtion State University - Pullman. Pipelines are designed around [PlantCV](https://github.com/danforthcenter/plantcv)

## Installation

Install latest release

`pip install cppcpyutils`

Install dev version

`pip install git+https://github.com/CougPhenomics/cppcpyutils.git`

## Use

Please see the [documentation](https://CougPhenomics.github.io/cppcpyutils/)
